﻿using Microsoft.EntityFrameworkCore.Migrations;

#nullable disable

namespace Zoo.DAL.Migrations
{
    public partial class Initial : Migration
    {
        protected override void Up(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.CreateTable(
                name: "Sponsor",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", nullable: false),
                    Name = table.Column<string>(type: "nvarchar(50)", maxLength: 50, nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Sponsor", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "Zookeeper",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", nullable: false),
                    Name = table.Column<string>(type: "nvarchar(50)", maxLength: 50, nullable: false),
                    BadgeId = table.Column<int>(type: "int", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Zookeeper", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "Animal",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", nullable: false),
                    Name = table.Column<string>(type: "nvarchar(50)", maxLength: 50, nullable: false),
                    DateOfBirth = table.Column<DateTime>(type: "datetime2", nullable: false),
                    Weight = table.Column<double>(type: "float", nullable: true),
                    ZookeeperId = table.Column<Guid>(type: "uniqueidentifier", nullable: true)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Animal", x => x.Id);
                    table.ForeignKey(
                        name: "FK_Animal_Zookeeper_ZookeeperId",
                        column: x => x.ZookeeperId,
                        principalTable: "Zookeeper",
                        principalColumn: "Id");
                });

            migrationBuilder.CreateTable(
                name: "Sponsorship",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", nullable: false),
                    MonthlyAmount = table.Column<decimal>(type: "decimal(10,2)", nullable: false),
                    IsActive = table.Column<bool>(type: "bit", nullable: false),
                    AnimalId = table.Column<Guid>(type: "uniqueidentifier", nullable: true),
                    SponsorId = table.Column<Guid>(type: "uniqueidentifier", nullable: true)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Sponsorship", x => x.Id);
                    table.ForeignKey(
                        name: "FK_Sponsorship_Animal_AnimalId",
                        column: x => x.AnimalId,
                        principalTable: "Animal",
                        principalColumn: "Id");
                    table.ForeignKey(
                        name: "FK_Sponsorship_Sponsor_SponsorId",
                        column: x => x.SponsorId,
                        principalTable: "Sponsor",
                        principalColumn: "Id");
                });

            migrationBuilder.InsertData(
                table: "Sponsor",
                columns: new[] { "Id", "Name" },
                values: new object[] { new Guid("1d2c594a-a66e-4191-958f-c02bd476a81d"), "Milan Bezdíček" });

            migrationBuilder.InsertData(
                table: "Zookeeper",
                columns: new[] { "Id", "BadgeId", "Name" },
                values: new object[] { new Guid("7c6eb4e4-51e5-4016-b44b-addbe624bb2b"), 10, "Pavel Petříček" });

            migrationBuilder.InsertData(
                table: "Zookeeper",
                columns: new[] { "Id", "BadgeId", "Name" },
                values: new object[] { new Guid("9db6796b-f38b-4496-bce2-27d5eb3dc391"), 585, "Petr Pavlíček" });

            migrationBuilder.InsertData(
                table: "Animal",
                columns: new[] { "Id", "DateOfBirth", "Name", "Weight", "ZookeeperId" },
                values: new object[,]
                {
                    { new Guid("0dab370e-3009-4afa-bc1b-708c1434d596"), new DateTime(2015, 5, 2, 0, 0, 0, 0, DateTimeKind.Unspecified), "Leo the Giraffe", 1320.0, new Guid("7c6eb4e4-51e5-4016-b44b-addbe624bb2b") },
                    { new Guid("10fd6cad-5040-47cd-b4fd-b08aabe84354"), new DateTime(2019, 5, 25, 0, 0, 0, 0, DateTimeKind.Unspecified), "Melvin the Porcupine", 9.5, new Guid("9db6796b-f38b-4496-bce2-27d5eb3dc391") },
                    { new Guid("340c390b-1efb-49e3-a567-5842d3428de0"), new DateTime(2010, 12, 25, 0, 0, 0, 0, DateTimeKind.Unspecified), "Alan the Crocodile", 1050.0, new Guid("7c6eb4e4-51e5-4016-b44b-addbe624bb2b") },
                    { new Guid("63c40a02-5451-414f-8543-1349e021bebb"), new DateTime(2018, 10, 9, 0, 0, 0, 0, DateTimeKind.Unspecified), "Coco the Gorilla", 140.0, new Guid("9db6796b-f38b-4496-bce2-27d5eb3dc391") }
                });

            migrationBuilder.InsertData(
                table: "Sponsorship",
                columns: new[] { "Id", "AnimalId", "IsActive", "MonthlyAmount", "SponsorId" },
                values: new object[] { new Guid("541bc401-0f55-4a16-ac94-eadb0b05294c"), new Guid("10fd6cad-5040-47cd-b4fd-b08aabe84354"), true, 25000m, new Guid("1d2c594a-a66e-4191-958f-c02bd476a81d") });

            migrationBuilder.InsertData(
                table: "Sponsorship",
                columns: new[] { "Id", "AnimalId", "IsActive", "MonthlyAmount", "SponsorId" },
                values: new object[] { new Guid("fe3f73cb-e975-417b-b57a-11682e3050bd"), new Guid("0dab370e-3009-4afa-bc1b-708c1434d596"), true, 10000m, new Guid("1d2c594a-a66e-4191-958f-c02bd476a81d") });

            migrationBuilder.CreateIndex(
                name: "IX_Animal_ZookeeperId",
                table: "Animal",
                column: "ZookeeperId");

            migrationBuilder.CreateIndex(
                name: "IX_Sponsorship_AnimalId",
                table: "Sponsorship",
                column: "AnimalId");

            migrationBuilder.CreateIndex(
                name: "IX_Sponsorship_SponsorId",
                table: "Sponsorship",
                column: "SponsorId");
        }

        protected override void Down(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.DropTable(
                name: "Sponsorship");

            migrationBuilder.DropTable(
                name: "Animal");

            migrationBuilder.DropTable(
                name: "Sponsor");

            migrationBuilder.DropTable(
                name: "Zookeeper");
        }
    }
}
