﻿using Microsoft.EntityFrameworkCore;
using Zoo.DAL;
using Zoo.DAL.Models;

namespace Zoo.Infrastructure.Repository
{
    public class AnimalRepository : IAnimalRepository, IAsyncDisposable
    {
        private ZooDbContext _context;

        public AnimalRepository(ZooDbContext context)
        {
            _context = context;
        }

        public async Task DeleteAnimalAsync(Guid animalId)
        {
            var animalToDelete = await _context.Animal.SingleOrDefaultAsync(anim => anim.Id == animalId);
            _context.Animal.Remove(animalToDelete);
        }

        public async Task<Animal> GetAnimalByIdAsync(Guid id)
        {
            return await _context.Animal.SingleOrDefaultAsync(anim => anim.Id == id);
        }

        public async Task<IEnumerable<Animal>> GetAnimalsAsync()
        {
            return await _context.Animal.ToListAsync();
        }

        public async Task InsertAnimalAsync(Animal animal)
        {
            await _context.Animal.AddAsync(animal);
        }


        public void UpdateAnimal(Animal animal)
        {
            _context.Animal.Update(animal);
        }

        public async Task SaveAsync()
        {
            await _context.SaveChangesAsync();
        }

        public async ValueTask DisposeAsync()
        {
            await _context.DisposeAsync();
        }

    }
}
