﻿using Microsoft.EntityFrameworkCore;
using Zoo.DAL;
using Zoo.DAL.Models;

namespace Zoo.Infrastructure.Repository
{
    public class SponsorRepository : ISponsorRepository, IAsyncDisposable
    {
        private ZooDbContext _context;

        public SponsorRepository(ZooDbContext context)
        {
            _context = context;
        }

        public async Task DeleteSponsorAsync(Guid sponsorId)
        {
            var sponsorToDelete = await _context.Sponsor.SingleOrDefaultAsync(spon => spon.Id == sponsorId);
            _context.Sponsor.Remove(sponsorToDelete);
        }

        public async Task<Sponsor> GetZookepeerByIdAsync(Guid id)
        {
            return await _context.Sponsor.SingleOrDefaultAsync(spon => spon.Id == id);
        }

        public async Task<IEnumerable<Sponsor>> GetSponsorsAsync()
        {
            return await _context.Sponsor.ToListAsync();
        }

        public async Task InsertSponsorAsync(Sponsor sponsor)
        {
            await _context.Sponsor.AddAsync(sponsor);
        }


        public void UpdateSponsor(Sponsor sponsor)
        {
            _context.Sponsor.Update(sponsor);
        }

        public async Task SaveAsync()
        {
            await _context.SaveChangesAsync();
        }

        public async ValueTask DisposeAsync()
        {
            await _context.DisposeAsync();
        }


    }
}
