﻿using Microsoft.EntityFrameworkCore;
using Zoo.DAL;
using Zoo.DAL.Models;

namespace Zoo.Infrastructure.Repository
{
    public class SponsorshipRepository : ISponsorshipRepository, IAsyncDisposable
    {
        private ZooDbContext _context;

        public SponsorshipRepository(ZooDbContext context)
        {
            _context = context;
        }

        public async Task DeleteSponsorshipAsync(Guid sponsorshipId)
        {
            var sponsorshipToDelete = await _context.Sponsorship.SingleOrDefaultAsync(spon => spon.Id == sponsorshipId);
            _context.Sponsorship.Remove(sponsorshipToDelete);
        }

        public async Task<Sponsorship> GetZookepeerByIdAsync(Guid id)
        {
            return await _context.Sponsorship.SingleOrDefaultAsync(spon => spon.Id == id);
        }

        public async Task<IEnumerable<Sponsorship>> GetSponsorshipsAsync()
        {
            return await _context.Sponsorship.ToListAsync();
        }

        public async Task InsertSponsorshipAsync(Sponsorship sponsorship)
        {
            await _context.Sponsorship.AddAsync(sponsorship);
        }


        public void UpdateSponsorship(Sponsorship sponsorship)
        {
            _context.Sponsorship.Update(sponsorship);
        }

        public async Task SaveAsync()
        {
            await _context.SaveChangesAsync();
        }

        public async ValueTask DisposeAsync()
        {
            await _context.DisposeAsync();
        }


    }
}
