﻿using Microsoft.EntityFrameworkCore;
using Zoo.DAL;
using Zoo.DAL.Models;

namespace Zoo.Infrastructure.Repository
{
    public class ZookeeperRepository : IZookeeperRepository, IAsyncDisposable
    {
        private ZooDbContext _context;

        public ZookeeperRepository(ZooDbContext context)
        {
            _context = context;
        }

        public async Task DeleteZookeeperAsync(Guid zookeeperId)
        {
            var zookeeperToDelete = await _context.Zookeeper.SingleOrDefaultAsync(zook => zook.Id == zookeeperId);
            _context.Zookeeper.Remove(zookeeperToDelete);
        }

        public async Task<Zookeeper> GetZookepeerByIdAsync(Guid id)
        {
            return await _context.Zookeeper.SingleOrDefaultAsync(zook => zook.Id == id);
        }

        public async Task<IEnumerable<Zookeeper>> GetZookeepersAsync()
        {
            return await _context.Zookeeper.ToListAsync();
        }

        public async Task InsertZookeeperAsync(Zookeeper zookeeper)
        {
            await _context.Zookeeper.AddAsync(zookeeper);
        }


        public void UpdateZookeeper(Zookeeper zookeeper)
        {
            _context.Zookeeper.Update(zookeeper);
        }

        public async Task SaveAsync()
        {
            await _context.SaveChangesAsync();
        }

        public async ValueTask DisposeAsync()
        {
            await _context.DisposeAsync();
        }


    }
}
