﻿using Zoo.DAL.Models;
using Zoo.DAL.UnitOfWork;

await using IUnitOfWork unitOfWork = new UnitOfWork();

// Reading data

var animals = await unitOfWork.AnimalRepository.GetAnimalsAsync();

var animalsCount = animals.Count();

Console.WriteLine($"Animal count: {animalsCount}");

var allAnimalNames = $"All animals: {string.Join(",", animals.Select(anim => $"{anim.Name}"))}";

Console.WriteLine(allAnimalNames);

// Insert animal

var zookeepers = await unitOfWork.ZookeeperRepository.GetZookeepersAsync();
var firstZookeeper = zookeepers.First();

var sharkOrderNo = new Random().NextInt64(1, 100);
var animalToAdd = new Animal()
{
    DateOfBirth = new DateTime(2021, 2, 2),
    Name = $"Peter the Shark [{sharkOrderNo}]",
    Weight = 860,
    ZookeeperId = firstZookeeper.Id,
    Id = Guid.NewGuid()
};

await unitOfWork.AnimalRepository.InsertAnimalAsync(animalToAdd);

// Rename Leo the Giraffe

var animalsAll = await unitOfWork.AnimalRepository.GetAnimalsAsync();
var leoTheGiraffe = animalsAll.SingleOrDefault(anim => anim.Name.Contains("Leo"));

var giraffeOrderNo = new Random().NextInt64(1, 100);
leoTheGiraffe.Name = $"Leonard the Giraffe the [{giraffeOrderNo}]";

unitOfWork.AnimalRepository.UpdateAnimal(leoTheGiraffe);

await unitOfWork.CommitAsync();

// Read new data

var newAnimalList = await unitOfWork.AnimalRepository.GetAnimalsAsync();

var newAnimalNames = $"All animals: {string.Join(",", newAnimalList.Select(anim => $"{anim.Name}"))}";

Console.WriteLine($"New animal names:{Environment.NewLine}{newAnimalNames}");
